@@ -603,7 +603,9 @@ module.exports = {
 		"7.2.3",
 		"7.2.4",
 		"7.3.0",
-		"7.3.1"
+		"7.3.1",
+		"7.3.2",
+		"7.3.3"
 	],
 	"79.0.3931.0": [
 		"8.0.0-beta.1",
@@ -710,7 +712,10 @@ module.exports = {
 	"80.0.3987.163": [
 		"8.2.1",
 		"8.2.2",
-		"8.2.3"
+		"8.2.3",
+		"8.5.3",
+		"8.5.4",
+		"8.5.5"
 	],
 	"80.0.3987.165": [
 		"8.2.4",
@@ -718,7 +723,13 @@ module.exports = {
 		"8.3.0",
 		"8.3.1",
 		"8.3.2",
-		"8.3.3"
+		"8.3.3",
+		"8.3.4",
+		"8.4.0",
+		"8.4.1",
+		"8.5.0",
+		"8.5.1",
+		"8.5.2"
 	],
 	"82.0.4048.0": [
 		"9.0.0-beta.1",
@@ -827,6 +838,24 @@ module.exports = {
 	"83.0.4103.119": [
 		"9.0.5"
 	],
+	"83.0.4103.122": [
+		"9.1.0",
+		"9.1.1",
+		"9.1.2",
+		"9.2.0",
+		"9.2.1",
+		"9.3.0",
+		"9.3.1",
+		"9.3.2",
+		"9.3.3",
+		"9.3.4",
+		"9.3.5",
+		"9.4.0",
+		"9.4.1",
+		"9.4.2",
+		"9.4.3",
+		"9.4.4"
+	],
 	"84.0.4129.0": [
 		"10.0.0-beta.1",
 		"10.0.0-beta.2",
@@ -852,6 +881,37 @@ module.exports = {
 		"10.0.0-beta.3",
 		"10.0.0-beta.4"
 	],
+	"85.0.4181.1": [
+		"10.0.0-beta.8",
+		"10.0.0-beta.9"
+	],
+	"85.0.4183.19": [
+		"10.0.0-beta.10"
+	],
+	"85.0.4183.20": [
+		"10.0.0-beta.11"
+	],
+	"85.0.4183.26": [
+		"10.0.0-beta.12"
+	],
+	"85.0.4183.39": [
+		"10.0.0-beta.13",
+		"10.0.0-beta.14",
+		"10.0.0-beta.15",
+		"10.0.0-beta.17",
+		"10.0.0-beta.19",
+		"10.0.0-beta.20",
+		"10.0.0-beta.21"
+	],
+	"85.0.4183.70": [
+		"10.0.0-beta.23"
+	],
+	"85.0.4183.78": [
+		"10.0.0-beta.24"
+	],
+	"85.0.4183.80": [
+		"10.0.0-beta.25"
+	],
 	"82.0.4050.0": [
 		"10.0.0-nightly.20200209",
 		"10.0.0-nightly.20200210",
@@ -917,6 +977,82 @@ module.exports = {
 		"10.0.0-nightly.20200429",
 		"10.0.0-nightly.20200430"
 	],
+	"85.0.4183.84": [
+		"10.0.0"
+	],
+	"85.0.4183.86": [
+		"10.0.1"
+	],
+	"85.0.4183.87": [
+		"10.1.0"
+	],
+	"85.0.4183.93": [
+		"10.1.1"
+	],
+	"85.0.4183.98": [
+		"10.1.2"
+	],
+	"85.0.4183.121": [
+		"10.1.3",
+		"10.1.4",
+		"10.1.5",
+		"10.1.6",
+		"10.1.7",
+		"10.2.0",
+		"10.3.0",
+		"10.3.1",
+		"10.3.2",
+		"10.4.0",
+		"10.4.1",
+		"10.4.2",
+		"10.4.3",
+		"10.4.4",
+		"10.4.5",
+		"10.4.6",
+		"10.4.7"
+	],
+	"86.0.4234.0": [
+		"11.0.0-beta.1",
+		"11.0.0-beta.3",
+		"11.0.0-beta.4",
+		"11.0.0-beta.5",
+		"11.0.0-beta.6",
+		"11.0.0-beta.7",
+		"11.0.0-nightly.20200822",
+		"11.0.0-nightly.20200824",
+		"11.0.0-nightly.20200825",
+		"11.0.0-nightly.20200826",
+		"12.0.0-nightly.20200827",
+		"12.0.0-nightly.20200831",
+		"12.0.0-nightly.20200902",
+		"12.0.0-nightly.20200903",
+		"12.0.0-nightly.20200907",
+		"12.0.0-nightly.20200910",
+		"12.0.0-nightly.20200911",
+		"12.0.0-nightly.20200914"
+	],
+	"87.0.4251.1": [
+		"11.0.0-beta.8",
+		"11.0.0-beta.9",
+		"11.0.0-beta.11"
+	],
+	"87.0.4280.11": [
+		"11.0.0-beta.12",
+		"11.0.0-beta.13"
+	],
+	"87.0.4280.27": [
+		"11.0.0-beta.16",
+		"11.0.0-beta.17",
+		"11.0.0-beta.18",
+		"11.0.0-beta.19"
+	],
+	"87.0.4280.40": [
+		"11.0.0-beta.20"
+	],
+	"87.0.4280.47": [
+		"11.0.0-beta.22",
+		"11.0.0-beta.23"
+	],
 	"85.0.4156.0": [
 		"11.0.0-nightly.20200529"
 	],
@@ -932,5 +1068,291 @@ module.exports = {
 		"11.0.0-nightly.20200617",
 		"11.0.0-nightly.20200618",
 		"11.0.0-nightly.20200619"
+	],
+	"85.0.4179.0": [
+		"11.0.0-nightly.20200701",
+		"11.0.0-nightly.20200702",
+		"11.0.0-nightly.20200703",
+		"11.0.0-nightly.20200706",
+		"11.0.0-nightly.20200707",
+		"11.0.0-nightly.20200708",
+		"11.0.0-nightly.20200709"
+	],
+	"86.0.4203.0": [
+		"11.0.0-nightly.20200716",
+		"11.0.0-nightly.20200717",
+		"11.0.0-nightly.20200720",
+		"11.0.0-nightly.20200721"
+	],
+	"86.0.4209.0": [
+		"11.0.0-nightly.20200723",
+		"11.0.0-nightly.20200724",
+		"11.0.0-nightly.20200729",
+		"11.0.0-nightly.20200730",
+		"11.0.0-nightly.20200731",
+		"11.0.0-nightly.20200803",
+		"11.0.0-nightly.20200804",
+		"11.0.0-nightly.20200805",
+		"11.0.0-nightly.20200811",
+		"11.0.0-nightly.20200812"
+	],
+	"87.0.4280.60": [
+		"11.0.0",
+		"11.0.1"
+	],
+	"87.0.4280.67": [
+		"11.0.2",
+		"11.0.3",
+		"11.0.4"
+	],
+	"87.0.4280.88": [
+		"11.0.5",
+		"11.1.0",
+		"11.1.1"
+	],
+	"87.0.4280.141": [
+		"11.2.0",
+		"11.2.1",
+		"11.2.2",
+		"11.2.3",
+		"11.3.0",
+		"11.4.0",
+		"11.4.1",
+		"11.4.2",
+		"11.4.3",
+		"11.4.4",
+		"11.4.5",
+		"11.4.6",
+		"11.4.7"
+	],
+	"89.0.4328.0": [
+		"12.0.0-beta.1",
+		"12.0.0-beta.3",
+		"12.0.0-beta.4",
+		"12.0.0-beta.5",
+		"12.0.0-beta.6",
+		"12.0.0-beta.7",
+		"12.0.0-beta.8",
+		"12.0.0-beta.9",
+		"12.0.0-beta.10",
+		"12.0.0-beta.11",
+		"12.0.0-beta.12",
+		"12.0.0-beta.14",
+		"13.0.0-nightly.20201119",
+		"13.0.0-nightly.20201123",
+		"13.0.0-nightly.20201124",
+		"13.0.0-nightly.20201126",
+		"13.0.0-nightly.20201127",
+		"13.0.0-nightly.20201130",
+		"13.0.0-nightly.20201201",
+		"13.0.0-nightly.20201202",
+		"13.0.0-nightly.20201203",
+		"13.0.0-nightly.20201204",
+		"13.0.0-nightly.20201207",
+		"13.0.0-nightly.20201208",
+		"13.0.0-nightly.20201209",
+		"13.0.0-nightly.20201210",
+		"13.0.0-nightly.20201211",
+		"13.0.0-nightly.20201214"
+	],
+	"89.0.4348.1": [
+		"12.0.0-beta.16",
+		"12.0.0-beta.18",
+		"12.0.0-beta.19",
+		"12.0.0-beta.20"
+	],
+	"89.0.4388.2": [
+		"12.0.0-beta.21",
+		"12.0.0-beta.22",
+		"12.0.0-beta.23",
+		"12.0.0-beta.24",
+		"12.0.0-beta.25",
+		"12.0.0-beta.26"
+	],
+	"89.0.4389.23": [
+		"12.0.0-beta.27",
+		"12.0.0-beta.28",
+		"12.0.0-beta.29"
+	],
+	"89.0.4389.58": [
+		"12.0.0-beta.30",
+		"12.0.0-beta.31"
+	],
+	"87.0.4268.0": [
+		"12.0.0-nightly.20201013",
+		"12.0.0-nightly.20201014",
+		"12.0.0-nightly.20201015"
+	],
+	"88.0.4292.0": [
+		"12.0.0-nightly.20201023",
+		"12.0.0-nightly.20201026"
+	],
+	"88.0.4306.0": [
+		"12.0.0-nightly.20201030",
+		"12.0.0-nightly.20201102",
+		"12.0.0-nightly.20201103",
+		"12.0.0-nightly.20201104",
+		"12.0.0-nightly.20201105",
+		"12.0.0-nightly.20201106",
+		"12.0.0-nightly.20201111",
+		"12.0.0-nightly.20201112"
+	],
+	"88.0.4324.0": [
+		"12.0.0-nightly.20201116"
+	],
+	"89.0.4389.69": [
+		"12.0.0"
+	],
+	"89.0.4389.82": [
+		"12.0.1"
+	],
+	"89.0.4389.90": [
+		"12.0.2"
+	],
+	"89.0.4389.114": [
+		"12.0.3",
+		"12.0.4"
+	],
+	"89.0.4389.128": [
+		"12.0.5",
+		"12.0.6",
+		"12.0.7",
+		"12.0.8",
+		"12.0.9"
+	],
+	"90.0.4402.0": [
+		"13.0.0-beta.2",
+		"13.0.0-beta.3",
+		"13.0.0-nightly.20210210",
+		"13.0.0-nightly.20210211",
+		"13.0.0-nightly.20210212",
+		"13.0.0-nightly.20210216",
+		"13.0.0-nightly.20210217",
+		"13.0.0-nightly.20210218",
+		"13.0.0-nightly.20210219",
+		"13.0.0-nightly.20210222",
+		"13.0.0-nightly.20210225",
+		"13.0.0-nightly.20210226",
+		"13.0.0-nightly.20210301",
+		"13.0.0-nightly.20210302",
+		"13.0.0-nightly.20210303",
+		"14.0.0-nightly.20210304"
+	],
+	"90.0.4415.0": [
+		"13.0.0-beta.4",
+		"13.0.0-beta.5",
+		"13.0.0-beta.6",
+		"13.0.0-beta.7",
+		"13.0.0-beta.8",
+		"13.0.0-beta.9",
+		"13.0.0-beta.11",
+		"13.0.0-beta.12",
+		"13.0.0-beta.13",
+		"14.0.0-nightly.20210305",
+		"14.0.0-nightly.20210308",
+		"14.0.0-nightly.20210309",
+		"14.0.0-nightly.20210311",
+		"14.0.0-nightly.20210315",
+		"14.0.0-nightly.20210316",
+		"14.0.0-nightly.20210317",
+		"14.0.0-nightly.20210318",
+		"14.0.0-nightly.20210319",
+		"14.0.0-nightly.20210323",
+		"14.0.0-nightly.20210324",
+		"14.0.0-nightly.20210325",
+		"14.0.0-nightly.20210326",
+		"14.0.0-nightly.20210329",
+		"14.0.0-nightly.20210330"
+	],
+	"91.0.4448.0": [
+		"13.0.0-beta.14",
+		"13.0.0-beta.16",
+		"13.0.0-beta.17",
+		"13.0.0-beta.18",
+		"13.0.0-beta.20",
+		"14.0.0-nightly.20210331",
+		"14.0.0-nightly.20210401",
+		"14.0.0-nightly.20210402",
+		"14.0.0-nightly.20210406",
+		"14.0.0-nightly.20210407",
+		"14.0.0-nightly.20210408",
+		"14.0.0-nightly.20210409",
+		"14.0.0-nightly.20210413"
+	],
+	"91.0.4472.33": [
+		"13.0.0-beta.21",
+		"13.0.0-beta.22",
+		"13.0.0-beta.23"
+	],
+	"91.0.4472.38": [
+		"13.0.0-beta.24",
+		"13.0.0-beta.26",
+		"13.0.0-beta.27",
+		"13.0.0-beta.28"
+	],
+	"89.0.4349.0": [
+		"13.0.0-nightly.20201215",
+		"13.0.0-nightly.20201216",
+		"13.0.0-nightly.20201221",
+		"13.0.0-nightly.20201222"
+	],
+	"89.0.4359.0": [
+		"13.0.0-nightly.20201223",
+		"13.0.0-nightly.20210104",
+		"13.0.0-nightly.20210108",
+		"13.0.0-nightly.20210111"
+	],
+	"89.0.4386.0": [
+		"13.0.0-nightly.20210113",
+		"13.0.0-nightly.20210114",
+		"13.0.0-nightly.20210118",
+		"13.0.0-nightly.20210122",
+		"13.0.0-nightly.20210125"
+	],
+	"89.0.4389.0": [
+		"13.0.0-nightly.20210127",
+		"13.0.0-nightly.20210128",
+		"13.0.0-nightly.20210129",
+		"13.0.0-nightly.20210201",
+		"13.0.0-nightly.20210202",
+		"13.0.0-nightly.20210203",
+		"13.0.0-nightly.20210205",
+		"13.0.0-nightly.20210208",
+		"13.0.0-nightly.20210209"
+	],
+	"91.0.4472.69": [
+		"13.0.0"
+	],
+	"92.0.4475.0": [
+		"14.0.0-nightly.20210426",
+		"14.0.0-nightly.20210427"
+	],
+	"92.0.4488.0": [
+		"14.0.0-nightly.20210430",
+		"14.0.0-nightly.20210503"
+	],
+	"92.0.4496.0": [
+		"14.0.0-nightly.20210505"
+	],
+	"92.0.4498.0": [
+		"14.0.0-nightly.20210506"
+	],
+	"92.0.4499.0": [
+		"14.0.0-nightly.20210507",
+		"14.0.0-nightly.20210510",
+		"14.0.0-nightly.20210511",
+		"14.0.0-nightly.20210512",
+		"14.0.0-nightly.20210513"
+	],
+	"92.0.4505.0": [
+		"14.0.0-nightly.20210514",
+		"14.0.0-nightly.20210517",
+		"14.0.0-nightly.20210518",
+		"14.0.0-nightly.20210519"
+	],
+	"92.0.4511.0": [
+		"14.0.0-nightly.20210520",
+		"14.0.0-nightly.20210523",
+		"14.0.0-nightly.20210524"
 	]
 };
\ No newline at end of file
