@@ -441,6 +441,8 @@ module.exports = {
 	"7.2.4": "78.0.3904.130",
 	"7.3.0": "78.0.3904.130",
 	"7.3.1": "78.0.3904.130",
+	"7.3.2": "78.0.3904.130",
+	"7.3.3": "78.0.3904.130",
 	"8.0.0-beta.1": "79.0.3931.0",
 	"8.0.0-beta.2": "79.0.3931.0",
 	"8.0.0-beta.3": "80.0.3955.0",
@@ -520,6 +522,15 @@ module.exports = {
 	"8.3.1": "80.0.3987.165",
 	"8.3.2": "80.0.3987.165",
 	"8.3.3": "80.0.3987.165",
+	"8.3.4": "80.0.3987.165",
+	"8.4.0": "80.0.3987.165",
+	"8.4.1": "80.0.3987.165",
+	"8.5.0": "80.0.3987.165",
+	"8.5.1": "80.0.3987.165",
+	"8.5.2": "80.0.3987.165",
+	"8.5.3": "80.0.3987.163",
+	"8.5.4": "80.0.3987.163",
+	"8.5.5": "80.0.3987.163",
 	"9.0.0-beta.1": "82.0.4048.0",
 	"9.0.0-beta.2": "82.0.4048.0",
 	"9.0.0-beta.3": "82.0.4048.0",
@@ -585,10 +596,41 @@ module.exports = {
 	"9.0.3": "83.0.4103.100",
 	"9.0.4": "83.0.4103.104",
 	"9.0.5": "83.0.4103.119",
+	"9.1.0": "83.0.4103.122",
+	"9.1.1": "83.0.4103.122",
+	"9.1.2": "83.0.4103.122",
+	"9.2.0": "83.0.4103.122",
+	"9.2.1": "83.0.4103.122",
+	"9.3.0": "83.0.4103.122",
+	"9.3.1": "83.0.4103.122",
+	"9.3.2": "83.0.4103.122",
+	"9.3.3": "83.0.4103.122",
+	"9.3.4": "83.0.4103.122",
+	"9.3.5": "83.0.4103.122",
+	"9.4.0": "83.0.4103.122",
+	"9.4.1": "83.0.4103.122",
+	"9.4.2": "83.0.4103.122",
+	"9.4.3": "83.0.4103.122",
+	"9.4.4": "83.0.4103.122",
 	"10.0.0-beta.1": "84.0.4129.0",
 	"10.0.0-beta.2": "84.0.4129.0",
 	"10.0.0-beta.3": "85.0.4161.2",
 	"10.0.0-beta.4": "85.0.4161.2",
+	"10.0.0-beta.8": "85.0.4181.1",
+	"10.0.0-beta.9": "85.0.4181.1",
+	"10.0.0-beta.10": "85.0.4183.19",
+	"10.0.0-beta.11": "85.0.4183.20",
+	"10.0.0-beta.12": "85.0.4183.26",
+	"10.0.0-beta.13": "85.0.4183.39",
+	"10.0.0-beta.14": "85.0.4183.39",
+	"10.0.0-beta.15": "85.0.4183.39",
+	"10.0.0-beta.17": "85.0.4183.39",
+	"10.0.0-beta.19": "85.0.4183.39",
+	"10.0.0-beta.20": "85.0.4183.39",
+	"10.0.0-beta.21": "85.0.4183.39",
+	"10.0.0-beta.23": "85.0.4183.70",
+	"10.0.0-beta.24": "85.0.4183.78",
+	"10.0.0-beta.25": "85.0.4183.80",
 	"10.0.0-nightly.20200209": "82.0.4050.0",
 	"10.0.0-nightly.20200210": "82.0.4050.0",
 	"10.0.0-nightly.20200211": "82.0.4050.0",
@@ -649,6 +691,46 @@ module.exports = {
 	"10.0.0-nightly.20200519": "84.0.4129.0",
 	"10.0.0-nightly.20200520": "84.0.4129.0",
 	"10.0.0-nightly.20200521": "84.0.4129.0",
+	"10.0.0": "85.0.4183.84",
+	"10.0.1": "85.0.4183.86",
+	"10.1.0": "85.0.4183.87",
+	"10.1.1": "85.0.4183.93",
+	"10.1.2": "85.0.4183.98",
+	"10.1.3": "85.0.4183.121",
+	"10.1.4": "85.0.4183.121",
+	"10.1.5": "85.0.4183.121",
+	"10.1.6": "85.0.4183.121",
+	"10.1.7": "85.0.4183.121",
+	"10.2.0": "85.0.4183.121",
+	"10.3.0": "85.0.4183.121",
+	"10.3.1": "85.0.4183.121",
+	"10.3.2": "85.0.4183.121",
+	"10.4.0": "85.0.4183.121",
+	"10.4.1": "85.0.4183.121",
+	"10.4.2": "85.0.4183.121",
+	"10.4.3": "85.0.4183.121",
+	"10.4.4": "85.0.4183.121",
+	"10.4.5": "85.0.4183.121",
+	"10.4.6": "85.0.4183.121",
+	"10.4.7": "85.0.4183.121",
+	"11.0.0-beta.1": "86.0.4234.0",
+	"11.0.0-beta.3": "86.0.4234.0",
+	"11.0.0-beta.4": "86.0.4234.0",
+	"11.0.0-beta.5": "86.0.4234.0",
+	"11.0.0-beta.6": "86.0.4234.0",
+	"11.0.0-beta.7": "86.0.4234.0",
+	"11.0.0-beta.8": "87.0.4251.1",
+	"11.0.0-beta.9": "87.0.4251.1",
+	"11.0.0-beta.11": "87.0.4251.1",
+	"11.0.0-beta.12": "87.0.4280.11",
+	"11.0.0-beta.13": "87.0.4280.11",
+	"11.0.0-beta.16": "87.0.4280.27",
+	"11.0.0-beta.17": "87.0.4280.27",
+	"11.0.0-beta.18": "87.0.4280.27",
+	"11.0.0-beta.19": "87.0.4280.27",
+	"11.0.0-beta.20": "87.0.4280.40",
+	"11.0.0-beta.22": "87.0.4280.47",
+	"11.0.0-beta.23": "87.0.4280.47",
 	"11.0.0-nightly.20200525": "84.0.4129.0",
 	"11.0.0-nightly.20200526": "84.0.4129.0",
 	"11.0.0-nightly.20200529": "85.0.4156.0",
@@ -662,5 +744,227 @@ module.exports = {
 	"11.0.0-nightly.20200616": "85.0.4162.0",
 	"11.0.0-nightly.20200617": "85.0.4162.0",
 	"11.0.0-nightly.20200618": "85.0.4162.0",
-	"11.0.0-nightly.20200619": "85.0.4162.0"
+	"11.0.0-nightly.20200619": "85.0.4162.0",
+	"11.0.0-nightly.20200701": "85.0.4179.0",
+	"11.0.0-nightly.20200702": "85.0.4179.0",
+	"11.0.0-nightly.20200703": "85.0.4179.0",
+	"11.0.0-nightly.20200706": "85.0.4179.0",
+	"11.0.0-nightly.20200707": "85.0.4179.0",
+	"11.0.0-nightly.20200708": "85.0.4179.0",
+	"11.0.0-nightly.20200709": "85.0.4179.0",
+	"11.0.0-nightly.20200716": "86.0.4203.0",
+	"11.0.0-nightly.20200717": "86.0.4203.0",
+	"11.0.0-nightly.20200720": "86.0.4203.0",
+	"11.0.0-nightly.20200721": "86.0.4203.0",
+	"11.0.0-nightly.20200723": "86.0.4209.0",
+	"11.0.0-nightly.20200724": "86.0.4209.0",
+	"11.0.0-nightly.20200729": "86.0.4209.0",
+	"11.0.0-nightly.20200730": "86.0.4209.0",
+	"11.0.0-nightly.20200731": "86.0.4209.0",
+	"11.0.0-nightly.20200803": "86.0.4209.0",
+	"11.0.0-nightly.20200804": "86.0.4209.0",
+	"11.0.0-nightly.20200805": "86.0.4209.0",
+	"11.0.0-nightly.20200811": "86.0.4209.0",
+	"11.0.0-nightly.20200812": "86.0.4209.0",
+	"11.0.0-nightly.20200822": "86.0.4234.0",
+	"11.0.0-nightly.20200824": "86.0.4234.0",
+	"11.0.0-nightly.20200825": "86.0.4234.0",
+	"11.0.0-nightly.20200826": "86.0.4234.0",
+	"11.0.0": "87.0.4280.60",
+	"11.0.1": "87.0.4280.60",
+	"11.0.2": "87.0.4280.67",
+	"11.0.3": "87.0.4280.67",
+	"11.0.4": "87.0.4280.67",
+	"11.0.5": "87.0.4280.88",
+	"11.1.0": "87.0.4280.88",
+	"11.1.1": "87.0.4280.88",
+	"11.2.0": "87.0.4280.141",
+	"11.2.1": "87.0.4280.141",
+	"11.2.2": "87.0.4280.141",
+	"11.2.3": "87.0.4280.141",
+	"11.3.0": "87.0.4280.141",
+	"11.4.0": "87.0.4280.141",
+	"11.4.1": "87.0.4280.141",
+	"11.4.2": "87.0.4280.141",
+	"11.4.3": "87.0.4280.141",
+	"11.4.4": "87.0.4280.141",
+	"11.4.5": "87.0.4280.141",
+	"11.4.6": "87.0.4280.141",
+	"11.4.7": "87.0.4280.141",
+	"12.0.0-beta.1": "89.0.4328.0",
+	"12.0.0-beta.3": "89.0.4328.0",
+	"12.0.0-beta.4": "89.0.4328.0",
+	"12.0.0-beta.5": "89.0.4328.0",
+	"12.0.0-beta.6": "89.0.4328.0",
+	"12.0.0-beta.7": "89.0.4328.0",
+	"12.0.0-beta.8": "89.0.4328.0",
+	"12.0.0-beta.9": "89.0.4328.0",
+	"12.0.0-beta.10": "89.0.4328.0",
+	"12.0.0-beta.11": "89.0.4328.0",
+	"12.0.0-beta.12": "89.0.4328.0",
+	"12.0.0-beta.14": "89.0.4328.0",
+	"12.0.0-beta.16": "89.0.4348.1",
+	"12.0.0-beta.18": "89.0.4348.1",
+	"12.0.0-beta.19": "89.0.4348.1",
+	"12.0.0-beta.20": "89.0.4348.1",
+	"12.0.0-beta.21": "89.0.4388.2",
+	"12.0.0-beta.22": "89.0.4388.2",
+	"12.0.0-beta.23": "89.0.4388.2",
+	"12.0.0-beta.24": "89.0.4388.2",
+	"12.0.0-beta.25": "89.0.4388.2",
+	"12.0.0-beta.26": "89.0.4388.2",
+	"12.0.0-beta.27": "89.0.4389.23",
+	"12.0.0-beta.28": "89.0.4389.23",
+	"12.0.0-beta.29": "89.0.4389.23",
+	"12.0.0-beta.30": "89.0.4389.58",
+	"12.0.0-beta.31": "89.0.4389.58",
+	"12.0.0-nightly.20200827": "86.0.4234.0",
+	"12.0.0-nightly.20200831": "86.0.4234.0",
+	"12.0.0-nightly.20200902": "86.0.4234.0",
+	"12.0.0-nightly.20200903": "86.0.4234.0",
+	"12.0.0-nightly.20200907": "86.0.4234.0",
+	"12.0.0-nightly.20200910": "86.0.4234.0",
+	"12.0.0-nightly.20200911": "86.0.4234.0",
+	"12.0.0-nightly.20200914": "86.0.4234.0",
+	"12.0.0-nightly.20201013": "87.0.4268.0",
+	"12.0.0-nightly.20201014": "87.0.4268.0",
+	"12.0.0-nightly.20201015": "87.0.4268.0",
+	"12.0.0-nightly.20201023": "88.0.4292.0",
+	"12.0.0-nightly.20201026": "88.0.4292.0",
+	"12.0.0-nightly.20201030": "88.0.4306.0",
+	"12.0.0-nightly.20201102": "88.0.4306.0",
+	"12.0.0-nightly.20201103": "88.0.4306.0",
+	"12.0.0-nightly.20201104": "88.0.4306.0",
+	"12.0.0-nightly.20201105": "88.0.4306.0",
+	"12.0.0-nightly.20201106": "88.0.4306.0",
+	"12.0.0-nightly.20201111": "88.0.4306.0",
+	"12.0.0-nightly.20201112": "88.0.4306.0",
+	"12.0.0-nightly.20201116": "88.0.4324.0",
+	"12.0.0": "89.0.4389.69",
+	"12.0.1": "89.0.4389.82",
+	"12.0.2": "89.0.4389.90",
+	"12.0.3": "89.0.4389.114",
+	"12.0.4": "89.0.4389.114",
+	"12.0.5": "89.0.4389.128",
+	"12.0.6": "89.0.4389.128",
+	"12.0.7": "89.0.4389.128",
+	"12.0.8": "89.0.4389.128",
+	"12.0.9": "89.0.4389.128",
+	"13.0.0-beta.2": "90.0.4402.0",
+	"13.0.0-beta.3": "90.0.4402.0",
+	"13.0.0-beta.4": "90.0.4415.0",
+	"13.0.0-beta.5": "90.0.4415.0",
+	"13.0.0-beta.6": "90.0.4415.0",
+	"13.0.0-beta.7": "90.0.4415.0",
+	"13.0.0-beta.8": "90.0.4415.0",
+	"13.0.0-beta.9": "90.0.4415.0",
+	"13.0.0-beta.11": "90.0.4415.0",
+	"13.0.0-beta.12": "90.0.4415.0",
+	"13.0.0-beta.13": "90.0.4415.0",
+	"13.0.0-beta.14": "91.0.4448.0",
+	"13.0.0-beta.16": "91.0.4448.0",
+	"13.0.0-beta.17": "91.0.4448.0",
+	"13.0.0-beta.18": "91.0.4448.0",
+	"13.0.0-beta.20": "91.0.4448.0",
+	"13.0.0-beta.21": "91.0.4472.33",
+	"13.0.0-beta.22": "91.0.4472.33",
+	"13.0.0-beta.23": "91.0.4472.33",
+	"13.0.0-beta.24": "91.0.4472.38",
+	"13.0.0-beta.26": "91.0.4472.38",
+	"13.0.0-beta.27": "91.0.4472.38",
+	"13.0.0-beta.28": "91.0.4472.38",
+	"13.0.0-nightly.20201119": "89.0.4328.0",
+	"13.0.0-nightly.20201123": "89.0.4328.0",
+	"13.0.0-nightly.20201124": "89.0.4328.0",
+	"13.0.0-nightly.20201126": "89.0.4328.0",
+	"13.0.0-nightly.20201127": "89.0.4328.0",
+	"13.0.0-nightly.20201130": "89.0.4328.0",
+	"13.0.0-nightly.20201201": "89.0.4328.0",
+	"13.0.0-nightly.20201202": "89.0.4328.0",
+	"13.0.0-nightly.20201203": "89.0.4328.0",
+	"13.0.0-nightly.20201204": "89.0.4328.0",
+	"13.0.0-nightly.20201207": "89.0.4328.0",
+	"13.0.0-nightly.20201208": "89.0.4328.0",
+	"13.0.0-nightly.20201209": "89.0.4328.0",
+	"13.0.0-nightly.20201210": "89.0.4328.0",
+	"13.0.0-nightly.20201211": "89.0.4328.0",
+	"13.0.0-nightly.20201214": "89.0.4328.0",
+	"13.0.0-nightly.20201215": "89.0.4349.0",
+	"13.0.0-nightly.20201216": "89.0.4349.0",
+	"13.0.0-nightly.20201221": "89.0.4349.0",
+	"13.0.0-nightly.20201222": "89.0.4349.0",
+	"13.0.0-nightly.20201223": "89.0.4359.0",
+	"13.0.0-nightly.20210104": "89.0.4359.0",
+	"13.0.0-nightly.20210108": "89.0.4359.0",
+	"13.0.0-nightly.20210111": "89.0.4359.0",
+	"13.0.0-nightly.20210113": "89.0.4386.0",
+	"13.0.0-nightly.20210114": "89.0.4386.0",
+	"13.0.0-nightly.20210118": "89.0.4386.0",
+	"13.0.0-nightly.20210122": "89.0.4386.0",
+	"13.0.0-nightly.20210125": "89.0.4386.0",
+	"13.0.0-nightly.20210127": "89.0.4389.0",
+	"13.0.0-nightly.20210128": "89.0.4389.0",
+	"13.0.0-nightly.20210129": "89.0.4389.0",
+	"13.0.0-nightly.20210201": "89.0.4389.0",
+	"13.0.0-nightly.20210202": "89.0.4389.0",
+	"13.0.0-nightly.20210203": "89.0.4389.0",
+	"13.0.0-nightly.20210205": "89.0.4389.0",
+	"13.0.0-nightly.20210208": "89.0.4389.0",
+	"13.0.0-nightly.20210209": "89.0.4389.0",
+	"13.0.0-nightly.20210210": "90.0.4402.0",
+	"13.0.0-nightly.20210211": "90.0.4402.0",
+	"13.0.0-nightly.20210212": "90.0.4402.0",
+	"13.0.0-nightly.20210216": "90.0.4402.0",
+	"13.0.0-nightly.20210217": "90.0.4402.0",
+	"13.0.0-nightly.20210218": "90.0.4402.0",
+	"13.0.0-nightly.20210219": "90.0.4402.0",
+	"13.0.0-nightly.20210222": "90.0.4402.0",
+	"13.0.0-nightly.20210225": "90.0.4402.0",
+	"13.0.0-nightly.20210226": "90.0.4402.0",
+	"13.0.0-nightly.20210301": "90.0.4402.0",
+	"13.0.0-nightly.20210302": "90.0.4402.0",
+	"13.0.0-nightly.20210303": "90.0.4402.0",
+	"13.0.0": "91.0.4472.69",
+	"14.0.0-nightly.20210304": "90.0.4402.0",
+	"14.0.0-nightly.20210305": "90.0.4415.0",
+	"14.0.0-nightly.20210308": "90.0.4415.0",
+	"14.0.0-nightly.20210309": "90.0.4415.0",
+	"14.0.0-nightly.20210311": "90.0.4415.0",
+	"14.0.0-nightly.20210315": "90.0.4415.0",
+	"14.0.0-nightly.20210316": "90.0.4415.0",
+	"14.0.0-nightly.20210317": "90.0.4415.0",
+	"14.0.0-nightly.20210318": "90.0.4415.0",
+	"14.0.0-nightly.20210319": "90.0.4415.0",
+	"14.0.0-nightly.20210323": "90.0.4415.0",
+	"14.0.0-nightly.20210324": "90.0.4415.0",
+	"14.0.0-nightly.20210325": "90.0.4415.0",
+	"14.0.0-nightly.20210326": "90.0.4415.0",
+	"14.0.0-nightly.20210329": "90.0.4415.0",
+	"14.0.0-nightly.20210330": "90.0.4415.0",
+	"14.0.0-nightly.20210331": "91.0.4448.0",
+	"14.0.0-nightly.20210401": "91.0.4448.0",
+	"14.0.0-nightly.20210402": "91.0.4448.0",
+	"14.0.0-nightly.20210406": "91.0.4448.0",
+	"14.0.0-nightly.20210407": "91.0.4448.0",
+	"14.0.0-nightly.20210408": "91.0.4448.0",
+	"14.0.0-nightly.20210409": "91.0.4448.0",
+	"14.0.0-nightly.20210413": "91.0.4448.0",
+	"14.0.0-nightly.20210426": "92.0.4475.0",
+	"14.0.0-nightly.20210427": "92.0.4475.0",
+	"14.0.0-nightly.20210430": "92.0.4488.0",
+	"14.0.0-nightly.20210503": "92.0.4488.0",
+	"14.0.0-nightly.20210505": "92.0.4496.0",
+	"14.0.0-nightly.20210506": "92.0.4498.0",
+	"14.0.0-nightly.20210507": "92.0.4499.0",
+	"14.0.0-nightly.20210510": "92.0.4499.0",
+	"14.0.0-nightly.20210511": "92.0.4499.0",
+	"14.0.0-nightly.20210512": "92.0.4499.0",
+	"14.0.0-nightly.20210513": "92.0.4499.0",
+	"14.0.0-nightly.20210514": "92.0.4505.0",
+	"14.0.0-nightly.20210517": "92.0.4505.0",
+	"14.0.0-nightly.20210518": "92.0.4505.0",
+	"14.0.0-nightly.20210519": "92.0.4505.0",
+	"14.0.0-nightly.20210520": "92.0.4511.0",
+	"14.0.0-nightly.20210523": "92.0.4511.0",
+	"14.0.0-nightly.20210524": "92.0.4511.0"
 };
\ No newline at end of file
